@@ -1,8 +1,9 @@
 from .main import (
-    pipeline,
+    filter_by_category,
     export_qiime_artifact,
     convert_biom_table,
     run_cmd,
     merge_metadata_and_taxonomy,
     n_largest_by_category,
+    extract_asvs_and_blast,
 )
